==> hexSticker_0.5.0.zip: hexSticker/NEWS.md <==
# CHANGES IN VERSION 0.5.0

+ remove deprecated `aes_()` (2025-09-18, Thu)

# CHANGES IN VERSION 0.4.8

+ support passing `expression()` as package name (via the `package` parameter) (2020-08-20, Thu)
  - <https://github.com/GuangchuangYu/hexSticker/issues/105>

# CHANGES IN VERSION 0.4.7

+ use Cairo and enable Antialias when saving sticker on Windows (2020-06-01, Mon)
  - <https://github.com/GuangchuangYu/hexSticker/pull/98>
  - <https://github.com/GuangchuangYu/hexSticker/issues/97>

CHANGES IN VERSION 0.4.6
------------------------
+ u_angle parameter to allow changing angle of url (2019-5-20, Mon)
  - <https://github.com/GuangchuangYu/hexSticker/issues/62>
+ white_around_sticker parameter to put white triangles in the corners (2019-03-14)
  - <https://github.com/GuangchuangYu/hexSticker/pull/56>
+ asp parameter in sticker <2019-01-14, Mon>
  - <https://github.com/GuangchuangYu/hexSticker/issues/17>

hexSticker 0.4.5
------------------------
 + dpi paramter in sticker <2018-09-10, Mon>
 + ... parameter in save_sticker <2018-09-03, Mon>
 
hexSticker 0.4.2
------------------------
 + update code according to the change +f geom_subview <2017-11-22, Wed>

hexSticker 0.4.0
------------------------
 + remove ggforce dependency <2017-06-19, Mon>

hexSticker 0.3.0
------------------------
 + URL at lower border +f sticker <2017-04-19, Wed>
   - https://github.com/GuangchuangYu/hexSticker/issues/9

hexSticker 0.2.1
------------------------
 + bug fixed +f whiteTrans <2017-04-19, Wed>
   - https://github.com/GuangchuangYu/hexSticker/pull/8

hexSticker 0.2.0
------------------------
 + support spotlight <2017-04-05, Wed>
   - <https://github.com/GuangchuangYu/hexSticker/issues/7>

hexSticker 0.1.0
------------------------
 + geom_hexagon, geom_pkgname, theme_sticker <2017-03-21, Tue>
 + use ggimage::geom_subview and ggimage::geom_image <2017-03-21, Tue>

hexSticker 0.0.2
------------------------
 + support select font typeface <2017-03-15, Wed>
   - https://github.com/GuangchuangYu/hexSticker/issues/4
 + move package name to top layer <2017-03-14, Tue>
   - https://github.com/GuangchuangYu/hexSticker/issues/3

hexSticker 0.0.1
------------------------
 + initial version based on my script to generate ggtree sticker <2017-03-13, Mon>
   - https://github.com/jotsetung/BioC-stickers/blob/master/ggtree/ggtree_sticker.R

==> hexSticker_0.5.1.zip: hexSticker/NEWS.md <==
# CHANGES IN VERSION 0.5.1

+ fix border line missing issue when border size is large (2026-01-21, Wed)
+ use `linewidth` to fix warning (2025-09-20, Sat, #190)

# CHANGES IN VERSION 0.5.0

+ remove deprecated `aes_()` (2025-09-18, Thu)

# CHANGES IN VERSION 0.4.8

+ support passing `expression()` as package name (via the `package` parameter) (2020-08-20, Thu)
  - <https://github.com/GuangchuangYu/hexSticker/issues/105>

# CHANGES IN VERSION 0.4.7

+ use Cairo and enable Antialias when saving sticker on Windows (2020-06-01, Mon)
  - <https://github.com/GuangchuangYu/hexSticker/pull/98>
  - <https://github.com/GuangchuangYu/hexSticker/issues/97>

CHANGES IN VERSION 0.4.6
------------------------
+ u_angle parameter to allow changing angle of url (2019-5-20, Mon)
  - <https://github.com/GuangchuangYu/hexSticker/issues/62>
+ white_around_sticker parameter to put white triangles in the corners (2019-03-14)
  - <https://github.com/GuangchuangYu/hexSticker/pull/56>
+ asp parameter in sticker <2019-01-14, Mon>
  - <https://github.com/GuangchuangYu/hexSticker/issues/17>

hexSticker 0.4.5
------------------------
 + dpi paramter in sticker <2018-09-10, Mon>
 + ... parameter in save_sticker <2018-09-03, Mon>
 
hexSticker 0.4.2
------------------------
 + update code according to the change +f geom_subview <2017-11-22, Wed>

hexSticker 0.4.0
------------------------
 + remove ggforce dependency <2017-06-19, Mon>

hexSticker 0.3.0
------------------------
 + URL at lower border +f sticker <2017-04-19, Wed>
   - https://github.com/GuangchuangYu/hexSticker/issues/9

hexSticker 0.2.1
------------------------
 + bug fixed +f whiteTrans <2017-04-19, Wed>
   - https://github.com/GuangchuangYu/hexSticker/pull/8

hexSticker 0.2.0
------------------------
 + support spotlight <2017-04-05, Wed>
   - <https://github.com/GuangchuangYu/hexSticker/issues/7>

hexSticker 0.1.0
------------------------
 + geom_hexagon, geom_pkgname, theme_sticker <2017-03-21, Tue>
 + use ggimage::geom_subview and ggimage::geom_image <2017-03-21, Tue>

hexSticker 0.0.2
------------------------
 + support select font typeface <2017-03-15, Wed>
   - https://github.com/GuangchuangYu/hexSticker/issues/4
 + move package name to top layer <2017-03-14, Tue>
   - https://github.com/GuangchuangYu/hexSticker/issues/3

hexSticker 0.0.1
------------------------
 + initial version based on my script to generate ggtree sticker <2017-03-13, Mon>
   - https://github.com/jotsetung/BioC-stickers/blob/master/ggtree/ggtree_sticker.R
